@@ -18,6 +18,8 @@
 #'
 #' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/performance.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
+#' @family functions to check model assumptions and and assess model quality
+#'
 #' @examples
 #' model <<- lm(len ~ supp + dose, data = ToothGrowth)
 #' check_homogeneity(model)
@@ -50,7 +52,7 @@ check_homogeneity.default <- function(x, method = c("bartlett", "fligner", "leve
   }
 
   if (length(pred) > 1) {
-    pred <- paste0("interaction(", paste0(pred, collapse = ", "), ")", collapse = "")
+    pred <- paste0("interaction(", toString(pred), ")", collapse = "")
   }
 
   f <- stats::as.formula(sprintf("%s ~ %s", resp, pred))
@@ -58,7 +60,7 @@ check_homogeneity.default <- function(x, method = c("bartlett", "fligner", "leve
   if (method == "auto") {
     check <- tryCatch(
       {
-        utils::capture.output(p <- check_normality(x))
+        utils::capture.output(p <- check_normality(x)) # nolint
         p
       },
       error = function(e) {
@@ -75,10 +77,10 @@ check_homogeneity.default <- function(x, method = c("bartlett", "fligner", "leve
   }
 
   if (method == "fligner") {
-    r <- stats::fligner.test(f, data = insight::get_data(x))
+    r <- stats::fligner.test(f, data = insight::get_data(x, verbose = FALSE))
     p.val <- r$p.value
   } else if (method == "bartlett") {
-    r <- stats::bartlett.test(f, data = insight::get_data(x))
+    r <- stats::bartlett.test(f, data = insight::get_data(x, verbose = FALSE))
     p.val <- r$p.value
   } else if (method == "levene") {
     insight::check_if_installed("car")
@@ -109,7 +111,7 @@ check_homogeneity.default <- function(x, method = c("bartlett", "fligner", "leve
 print.check_homogeneity <- function(x, ...) {
   method.string <- attributes(x)$method
   if (is.na(x)) {
-    warning(paste0("Could not perform ", method.string, "."), call. = FALSE)
+    insight::format_warning(paste0("Could not perform ", method.string, "."))
     invisible(NULL)
   } else if (x < 0.05) {
     insight::print_color(sprintf("Warning: Variances differ between groups (%s, p = %.3f).\n", method.string, x), "red")
@@ -147,13 +149,13 @@ check_homogeneity.afex_aov <- function(x, method = "levene", ...) {
   dv <- attr(x, "dv")
   id <- attr(x, "id")
   between <- names(attr(x, "between"))
-  is_covar <- sapply(attr(x, "between"), is.null)
+  is_covar <- vapply(attr(x, "between"), is.null, logical(1))
 
   ag_data <- stats::aggregate(data[, dv], data[, c(between, id)], mean)
   colnames(ag_data)[length(c(between, id)) + 1] <- dv
 
   if (any(is_covar)) {
-    insight::format_warning(
+    insight::format_alert(
       "Levene's test is not appropriate with quantitative explanatory variables. Testing assumption of homogeneity among factor groups only."
     )
     # ## TODO maybe add as option?
