@@ -65,13 +65,6 @@ check_itemscale <- function(x) {
   insight::check_if_installed("parameters")
 
   dataset <- attributes(x)$dataset
-
-  ## TODO: remove once parameters 0.18.3 or higher on CRAN
-  # backward compatibility to parameters 0.18.2
-  if (is.null(dataset)) {
-    dataset <- attributes(x)$data_set
-  }
-
   subscales <- parameters::closest_component(x)
 
   out <- lapply(sort(unique(subscales)), function(.subscale) {
@@ -86,11 +79,11 @@ check_itemscale <- function(x) {
 
     s_out <- data.frame(
       Item = columns,
-      Missings = sapply(items, function(i) sum(is.na(i)) / nrow(items)),
-      Mean = sapply(items, mean, na.rm = TRUE),
-      SD = sapply(items, stats::sd, na.rm = TRUE),
-      Skewness = sapply(items, function(i) as.numeric(datawizard::skewness(i))),
-      "Difficulty" = item_difficulty(items)$difficulty,
+      Missings = vapply(items, function(i) sum(is.na(i)) / nrow(items), numeric(1)),
+      Mean = vapply(items, mean, numeric(1), na.rm = TRUE),
+      SD = vapply(items, stats::sd, numeric(1), na.rm = TRUE),
+      Skewness = vapply(items, function(i) as.numeric(datawizard::skewness(i)), numeric(1)),
+      "Difficulty" = item_difficulty(items)$Difficulty,
       "Discrimination" = .item_discr,
       "alpha if deleted" = .item_alpha,
       stringsAsFactors = FALSE,
