@@ -16,17 +16,21 @@
 #' in the interval `[0, 1]`, with values closer to 1 indicating a more
 #' accurate model, and the logarithmic rule in the interval `[-Inf, 0]`,
 #' with values closer to 0 indicating a more accurate model.
-#' \cr \cr
+#'
 #' For `stan_lmer()` and `stan_glmer()` models, the predicted values
 #' are based on `posterior_predict()`, instead of `predict()`. Thus,
 #' results may differ more than expected from their non-Bayesian counterparts
 #' in **lme4**.
 #'
-#' @references Carvalho, A. (2016). An overview of applications of proper scoring rules. Decision Analysis 13, 223–242. \doi{10.1287/deca.2016.0337}
+#' @references
+#' Carvalho, A. (2016). An overview of applications of proper scoring rules.
+#' Decision Analysis 13, 223–242. \doi{10.1287/deca.2016.0337}
 #'
-#' @note Code is partially based on [GLMMadaptive::scoring_rules()](https://drizopoulos.github.io/GLMMadaptive/reference/scoring_rules.html).
+#' @note
+#' Code is partially based on
+#' [GLMMadaptive::scoring_rules()](https://drizopoulos.github.io/GLMMadaptive/reference/scoring_rules.html).
 #'
-#' @seealso [`performance_logloss()`][performance_logloss]
+#' @seealso [`performance_logloss()`]
 #'
 #' @examples
 #' ## Dobson (1990) Page 93: Randomized Controlled Trial :
@@ -41,7 +45,7 @@
 #'   data(Salamanders)
 #'   model <- glmmTMB(
 #'     count ~ spp + mined + (1 | site),
-#'     zi =  ~ spp + mined,
+#'     zi = ~ spp + mined,
 #'     family = nbinom2(),
 #'     data = Salamanders
 #'   )
@@ -56,19 +60,27 @@ performance_score <- function(model, verbose = TRUE, ...) {
     model <- model$fit
   }
 
-  if (is.null(minfo <- list(...)$model_info)) {
+  minfo <- list(...)$model_info
+  if (is.null(minfo)) {
     minfo <- suppressWarnings(insight::model_info(model, verbose = FALSE))
   }
 
   if (minfo$is_ordinal || minfo$is_multinomial) {
-    if (verbose) insight::print_color("Can't calculate proper scoring rules for ordinal, multinomial or cumulative link models.\n", "red")
+    if (verbose) {
+      insight::print_color("Can't calculate proper scoring rules for ordinal, multinomial or cumulative link models.\n", "red")
+    }
     return(list(logarithmic = NA, quadratic = NA, spherical = NA))
   }
 
   resp <- insight::get_response(model, verbose = verbose)
 
   if (!is.null(ncol(resp)) && ncol(resp) > 1) {
-    if (verbose) insight::print_color("Can't calculate proper scoring rules for models without integer response values.\n", "red")
+    if (verbose) {
+      insight::print_color(
+        "Can't calculate proper scoring rules for models without integer response values.\n",
+        "red"
+      )
+    }
     return(list(logarithmic = NA, quadratic = NA, spherical = NA))
   }
 
@@ -184,14 +196,7 @@ print.performance_score <- function(x, ...) {
       sum(stats::residuals(model, type = "pearson")^2) / stats::df.residual(model)
     }
   } else {
-    tryCatch(
-      {
-        sum(stats::residuals(model, type = "pearson")^2) / stats::df.residual(model)
-      },
-      error = function(e) {
-        0
-      }
-    )
+    .safe(sum(stats::residuals(model, type = "pearson")^2) / stats::df.residual(model), 0)
   }
 }
 
